==> haskell-hslua-module-system-1.1.2-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-system
version:              1.1.2
visibility:           public
id:                   hslua-module-system-1.1.2-7uvzlT6wvieInnXoOHbSC9
key:                  hslua-module-system-1.1.2-7uvzlT6wvieInnXoOHbSC9
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  99a3997418b0516e650707aec8243c52
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.2-7uvzlT6wvieInnXoOHbSC9
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5
    hslua-core-2.3.2-CioTfMG9Ml2Lkmjmm7zI9U
    hslua-marshalling-2.3.1-C0K1WOE0GsN7XQHCGiWLQP
    hslua-packaging-2.3.1-F21C19K6SCt2asti8GbAoA
    temporary-1.3-21QsMwE9nNF6lJAUe6UOiS text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-system-1.1.2-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-system.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-system
version:              1.1.2
visibility:           public
id:                   hslua-module-system-1.1.2-AvogJ1sbIlN8GFJLzItzUx
key:                  hslua-module-system-1.1.2-AvogJ1sbIlN8GFJLzItzUx
license:              MIT
copyright:            © 2019-2024 Albert Krewinkel <tarleb@hslua.org>
maintainer:           tarleb@hslua.org
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua
synopsis:             Lua module wrapper around Haskell'\''s System module.
description:
    Provides access to system information and
    functionality to Lua scripts via Haskell'\''s `System`
    module.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  49e511266b9228949ea0118c420e6e03
exposed:              True
exposed-modules:      HsLua.Module.System
hidden-modules:       HsLua.Module.SystemUtils
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-module-system-1.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-system
hs-libraries:         HShslua-module-system-1.1.2-AvogJ1sbIlN8GFJLzItzUx
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5
    hslua-core-2.3.2-HOcJGy0qfWY7QKXxvs4ZJF
    hslua-marshalling-2.3.1-7agN2QWyNEBCITFMYtnBjU
    hslua-packaging-2.3.1-9krlfKrvzgDELajnMQEMSq
    temporary-1.3-5WcjY7uJWNv1MIS9W1UhrX text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-system/html/hslua-module-system.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-system/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
